YARP 2.2.4 (2009-09-09)                                                {#v2_2_4}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.2.3...v2.2.4`):

```
    98	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    42	Lorenzo Natale <lorenzo.natale@iit.it>
    18	Ugo Pattacini <ugo.pattacini@iit.it>
     6	YARP Developers <yarp0-devel@lists.sourceforge.net>
     4	Arjan Gijsberts <arjan.gijsberts@idiap.ch>
     3	Francesco Nori <francesco.nori@iit.it>
     2	Alessandro Scalzo <alessandro.scalzo@iit.it>
     1	Giacomo Spigler <spiglerg@gmail.com>
     1	Giorgio Metta <giorgio.metta@iit.it>
```
